%%% Run this script to predict tsunami signal at Monterey tide gage
%%% in the 2010/02/27 and 2015/09/16 tsunami events,
%%% given each tsunami signal at DART 32412 and the gage's Response.
%%%
%%% Copyright (C) 2016, Elena Tolkova
%%% under the terms of FreeBSD License
%%% 
%%% For conditions of distribution and use, see License_FreeBSD.txt

clear all

%event='20100227'    % % % Select one of the two events
event='20150916'

% read-in tsunami data at DART 32412 (time(s), height (m))
% in the selected event (de-tided), time after the quake
record_at_32412=['WaveHeight_32412_',event,'.txt'];
[tt, serin]=textread(record_at_32412);

% read-in the MRY gage Response
[ttp, pulse]=textread('ResponseMRYto32412.txt');

% re-sample 32412 signal to 2-min sampling
intt=tt(1):120:tt(end);
inser=spline(tt,serin,intt);
nnt=length(intt);

% generate the prediction:
% convolve 32412 data with the pulse response
ntp=length(ttp);
nout=2*nnt+ntp;
outt=ttp(1)+60*((1:nout)-1)+intt(1);
outser(1:nout,1)=0;
j=0;
for i=1:nnt
    outser((j+1):(j+ntp))=outser((j+1):(j+ntp))+inser(i)*pulse;
    j=j+2;
end

%%% Compare with the measurements at the gage
% read-in tsunami data at Monterey gage (time(s), height (m))
% in the selected event (de-tided), time after the quake
record_at_MRY=['WaveHeight_MRY_',event,'.txt'];
[ttg, gg]=textread(record_at_MRY);

% plot the prediction vs. the measurements
figure
hold on
plot(ttg/3600,gg,'k','linewidth',1)       % gage record
plot(outt/3600,outser,'r','linewidth',1)  % forecast
xlabel('hour after EQ','fontsize',12)
ylabel('m','fontsize',12)
xlim([13 20])
grid on
title(['Prediction vs data at MRY in ',event],'fontsize',12)
legend('record','forecast')

